labeltools.label_vertical_moments_in_expr_with_numbered_chromatic_pitch_classes
===============================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_chromatic_pitch_classes.label_vertical_moments_in_expr_with_numbered_chromatic_pitch_classes
   :noindex:
